@@ -40,6 +40,7 @@ import (
 	"github.com/aws/aws-sdk-go/service/iam"
 
 	"github.com/openshift/cloud-credential-operator/pkg/apis"
+	minterv1 "github.com/openshift/cloud-credential-operator/pkg/apis/cloudcredential/v1"
 	ccaws "github.com/openshift/cloud-credential-operator/pkg/aws"
 	mockaws "github.com/openshift/cloud-credential-operator/pkg/aws/mock"
 
@@ -55,7 +56,6 @@ const (
 	testAWSAccessKeyID     = "FAKEAWSACCESSKEYID"
 	testInfraName          = "testcluster-abc123"
 	testAWSSecretAccessKey = "KEEPITSECRET"
-	testAWSRegion          = "test-region-2"
 )
 
 var (
@@ -104,6 +104,14 @@ func TestSecretAnnotatorReconcile(t *testing.T) {
 			},
 			validateAnnotationValue: constants.MintAnnotation,
 		},
+		{
+			name:     "operator disabled",
+			existing: []runtime.Object{testSecret(), testOperatorConfigMap("true")},
+			mockAWSClient: func(mockCtrl *gomock.Controller) *mockaws.MockClient {
+				mockAWSClient := mockaws.NewMockClient(mockCtrl)
+				return mockAWSClient
+			},
+		},
 		{
 			name:     "detect root user creds",
 			existing: []runtime.Object{testSecret()},
@@ -124,27 +132,12 @@ func TestSecretAnnotatorReconcile(t *testing.T) {
 				mockSimulatePrincipalPolicyCredMinterFail(mockAWSClient)
 
 				mockGetUser(mockAWSClient)
-				mockSimulatePrincipalPolicyCredPassthrough(mockAWSClient, testAWSRegion)
+				mockSimulatePrincipalPolicyCredPassthroughSuccess(mockAWSClient)
 
 				return mockAWSClient
 			},
 			validateAnnotationValue: constants.PassthroughAnnotation,
 		},
-		{
-			name:     "cred passthrough mode wrong region permission",
-			existing: []runtime.Object{testSecret()},
-			mockAWSClient: func(mockCtrl *gomock.Controller) *mockaws.MockClient {
-				mockAWSClient := mockaws.NewMockClient(mockCtrl)
-				mockGetUser(mockAWSClient)
-				mockSimulatePrincipalPolicyCredMinterFail(mockAWSClient)
-
-				mockGetUser(mockAWSClient)
-				mockSimulatePrincipalPolicyCredPassthrough(mockAWSClient, "expect-this-region")
-
-				return mockAWSClient
-			},
-			validateAnnotationValue: constants.InsufficientAnnotation,
-		},
 		{
 			name:     "useless creds",
 			existing: []runtime.Object{testSecret()},
@@ -192,11 +185,6 @@ func TestSecretAnnotatorReconcile(t *testing.T) {
 				Status: configv1.InfrastructureStatus{
 					Platform:           configv1.AWSPlatformType,
 					InfrastructureName: testInfraName,
-					PlatformStatus: &configv1.PlatformStatus{
-						AWS: &configv1.AWSPlatformStatus{
-							Region: testAWSRegion,
-						},
-					},
 				},
 			}
 
@@ -249,6 +237,18 @@ func testSecret() *corev1.Secret {
 	return s
 }
 
+func testOperatorConfigMap(disabled string) *corev1.ConfigMap {
+	return &corev1.ConfigMap{
+		ObjectMeta: metav1.ObjectMeta{
+			Name:      minterv1.CloudCredOperatorConfigMap,
+			Namespace: minterv1.CloudCredOperatorNamespace,
+		},
+		Data: map[string]string{
+			"disabled": disabled,
+		},
+	}
+}
+
 func mockGetRootUser(mockAWSClient *mockaws.MockClient) {
 	rootAcctNum := "123456789012"
 
@@ -286,30 +286,13 @@ func mockSimulatePrincipalPolicyCredMinterFail(mockAWSClient *mockaws.MockClient
 		})
 }
 
-func mockSimulatePrincipalPolicyCredPassthrough(mockAWSClient *mockaws.MockClient, expectedRegion string) {
+func mockSimulatePrincipalPolicyCredPassthroughSuccess(mockAWSClient *mockaws.MockClient) {
 	mockAWSClient.EXPECT().SimulatePrincipalPolicyPages(gomock.Any(), gomock.Any()).Return(nil).
 		Do(func(input *iam.SimulatePrincipalPolicyInput, f func(*iam.SimulatePolicyResponse, bool) bool) {
-			if checkRegionParamSet(input, expectedRegion) {
-				f(successfulSimulateResponse, true)
-			} else {
-				f(failedSimulationResponse, true)
-			}
+			f(successfulSimulateResponse, true)
 		})
 }
 
-func checkRegionParamSet(input *iam.SimulatePrincipalPolicyInput, expectedRegion string) bool {
-	for _, ctx := range input.ContextEntries {
-		if *ctx.ContextKeyName == "aws:RequestedRegion" {
-			for _, value := range ctx.ContextKeyValues {
-				if *value == expectedRegion {
-					return true
-				}
-			}
-		}
-	}
-	return false
-}
-
 func mockSimulatePrincipalPolicyCredPassthroughFail(mockAWSClient *mockaws.MockClient) {
 	mockAWSClient.EXPECT().SimulatePrincipalPolicyPages(gomock.Any(), gomock.Any()).Return(nil).
 		// Now in the Do() receive the lambda function f() so we can send it the failed result
